@@ -58,6 +58,7 @@ enum eCommandKind {
     kAbs,
     kFAbs,
     kP,
+    kTry,
     kInnerCommand,
     kCommand 
 };
@@ -243,6 +244,18 @@ void sWhile_delete(sWhile* self);
 void sWhile_save(sWhile* self, int fd);
 sWhile* sWhile_load(int fd);
 
+typedef struct
+{
+    sStatments* loops;
+    sStatments* loops2;
+} sTry;
+
+sTry* sTry_new(MANAGED sStatments* loops, MANAGED sStatments* loops2);
+void sTry_view(sTry* self);
+void sTry_delete(sTry* self);
+void sTry_save(sTry* self, int fd);
+sTry* sTry_load(int fd);
+
 typedef struct
 {
     sStatments* contents;
@@ -308,6 +321,16 @@ void sVar_delete(sVar* self);
 sVar* sVar_load(int fd);
 void sVar_save(sVar* self, int fd);
 
+typedef struct {
+    sStatments* mStatments;
+    vector_obj* mArgs;
+} sBlock;
+
+sBlock* sBlock_new(sStatments* statments, vector_obj* args);
+void sBlock_delete(sBlock* self);
+void sBlock_save(sBlock* self, int fd);
+sBlock* sBlock_load(int fd);
+
 typedef struct
 {
     int mKind;   // 0: string 1: var 2: redirect 3: statments 4:var2 5: statments2 6: block
@@ -499,4 +522,8 @@ extern vector_obj* gStackTraceFName;
 extern vector_obj* gStackTraceLineNum;
     // åե졼εϿ
 
+int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, BOOL finaly_exec, BOOL in_loop, BOOL* return_, vector_obj* blocks, BOOL try_);
+    // saphire_compile2ǥѥ뤷ѥ̤¹Ԥ롣
+    // verboseϼ¹Ԥ˼¹Ԥ륳ޥ̾ɽ뤫ɤ
+
 #endif
