@@ -97,6 +97,7 @@ char* gStatmentKindStrs[kCommand+1] = {
     "abs",
     "fabs",
     "p",
+    "try",
 //    "parse",
     "inner_command",
     "command"
@@ -1256,7 +1257,7 @@ void sArg_delete(sArg* self)
         break;
 
     case 5:
-        sStatments_delete(self->mBody);
+        sBlock_delete(self->mBody);
         break;
     }
 
@@ -1305,7 +1306,7 @@ void sArg_save(sArg* self, int fd)
             break;
 
         case 5:
-            sStatments_save(self->mBody, fd);
+            sBlock_save(self->mBody, fd);
             break;
     }
 }
@@ -1357,7 +1358,7 @@ sArg* sArg_load(int fd)
         break;
 
     case 5:
-        self->mBody = sStatments_load(fd);
+        self->mBody = sBlock_load(fd);
         break;
     }
 
@@ -1410,7 +1411,7 @@ void sArgTmp_delete(sArgTmp* self)
         break;
 
     case 6:
-        if(self->mBody) sStatments_delete(self->mBody);
+        if(self->mBody) sBlock_delete(self->mBody);
         break;
     }
 
@@ -1455,10 +1456,52 @@ void sSubshell_view(sSubshell* self)
     sStatments_view(self->contents);
 }
 
+//////////////////////////////////////////////////////////
+// sTry
+//////////////////////////////////////////////////////////
+sTry* sTry_new(MANAGED sStatments* loops, MANAGED sStatments* loops2)
+{
+    sTry* self = MALLOC(sizeof(sTry));
+
+    self->loops = loops;
+    self->loops2 = loops2;
+
+    return self;
+}
+
+void sTry_delete(sTry* self)
+{
+    sStatments_delete(self->loops);
+    sStatments_delete(self->loops2);
+
+    FREE(self);
+}
+
+void sTry_view(sTry* self)
+{
+    sStatments_view(self->loops);
+    sStatments_view(self->loops2);
+}
+
+void sTry_save(sTry* self, int fd)
+{
+    sStatments_save(self->loops, fd);
+    sStatments_save(self->loops2, fd);
+}
+
+sTry* sTry_load(int fd)
+{
+    sTry* self = MALLOC(sizeof(sTry));
+    
+    self->loops = sStatments_load(fd);
+    self->loops2 = sStatments_load(fd);
+    
+    return self;
+}
+
 //////////////////////////////////////////////////////////
 // sWhile
 //////////////////////////////////////////////////////////
-
 sWhile* sWhile_new(MANAGED sStatments* joukensiki, MANAGED sStatments* contents)
 {
     sWhile* self = MALLOC(sizeof(sWhile));
@@ -1660,6 +1703,10 @@ void sCommand_view(sCommand* self)
     case kWhile:
         sWhile_view(self->mExtra);
         break;
+        
+    case kTry:
+        sTry_view(self->mExtra);
+        break;
 
     case kSubshell:
         sSubshell_view(self->mExtra);
@@ -1716,6 +1763,10 @@ void sCommand_save(sCommand* self, int fd)
     case kWhile:
         sWhile_save(self->mExtra, fd);
         break;
+
+    case kTry:
+        sTry_save(self->mExtra, fd);
+        break;
         
     case kSubshell:
         sSubshell_save(self->mExtra, fd);
@@ -1774,6 +1825,10 @@ sCommand* sCommand_load(int fd)
     case kWhile:
         self->mExtra = sWhile_load(fd);
         break;
+
+    case kTry:
+        self->mExtra = sTry_load(fd);
+        break;
         
     case kSubshell:
         self->mExtra = sSubshell_load(fd);
@@ -1818,6 +1873,10 @@ void sCommand_delete(sCommand* self)
         sWhile_delete(self->mExtra);
         break;
 
+    case kTry:
+        sTry_delete(self->mExtra);
+        break;
+
     case kSubshell:
         sSubshell_delete(self->mExtra);
         break;
@@ -2733,7 +2792,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
     }
     if(tcgetpgrp(0) == getpgid(0)) {
         gSaphireBackground = FALSE;
-        mreset_tty();
+        //mreset_tty();
     }
     else {
         gSaphireBackground = TRUE;
@@ -3702,3 +3761,88 @@ void saphire_make_var_completion_list()
     (void)vector_sort(gSaphireVarCompletions, name_sort);
 }
 
+sBlock* sBlock_new(sStatments* statments, vector_obj* args)
+{
+    sBlock* self = MALLOC(sizeof(sBlock));
+
+    self->mStatments = statments;
+    self->mArgs = args;
+
+    return self;
+}
+
+void sBlock_delete(sBlock* self)
+{
+    sStatments_delete(self->mStatments);
+    int i;
+    const int max = vector_size(self->mArgs);
+    for(i=0; i<max; i++) {
+        string_delete(vector_item(self->mArgs, i));
+    }
+    vector_delete(self->mArgs);
+
+    FREE(self);
+}
+
+sBlock* sBlock_load(int fd)
+{
+    sBlock* self = MALLOC(sizeof(sBlock));
+    
+    self->mStatments = sStatments_load(fd);
+
+    self->mArgs = VECTOR_NEW(50);
+    int n;
+    if(read(fd, &n, sizeof(int)) < 0) {
+        perror("read");
+        exit(1);
+    }
+    int i;
+    for(i=0; i<n; i++) {
+        int n;
+        if(read(fd, &n, sizeof(int)) < 0) {
+            perror("read");
+            exit(1);
+        }
+        
+        char* buf = MALLOC(n+1);
+        if(read(fd, buf, n) < 0) {
+            perror("read");
+            exit(1);
+        }
+        buf[n] = 0;
+        string_obj* buf2 = STRING_NEW(buf);
+        FREE(buf);
+        
+        vector_add(self->mArgs, buf2);
+    }
+
+    return self;
+}
+
+void sBlock_save(sBlock* self, int fd)
+{
+    sStatments_save(self->mStatments, fd);
+
+    /// mArgs ///
+    int n = vector_size(self->mArgs);
+    if(write(fd, &n, sizeof(int)) < 0) {
+        perror("write");
+        exit(1);
+    }
+
+    int i;
+    for(i=0; i<n; i++) {
+        char* str = string_c_str(vector_item(self->mArgs, i));
+
+        int n = strlen(str);
+        if(write(fd, &n, sizeof(int)) < 0) {
+            perror("write");
+            exit(1);
+        }
+        if(write(fd, str, n) < 0) {
+            perror("write");
+            exit(1);
+        }
+    }
+}
+
